@@ -3,7 +3,7 @@ BEGIN {
   $POE::Component::FeedAggregator::AUTHORITY = 'cpan:GETTY';
 }
 BEGIN {
-  $POE::Component::FeedAggregator::VERSION = '0.008';
+  $POE::Component::FeedAggregator::VERSION = '0.900';
 }
 # ABSTRACT: Watch multiple feeds (Atom or RSS) for new headlines 
 
@@ -39,9 +39,10 @@ has tmpdir => (
 event feed_received => sub {
 	my ( $self, $kernel, @args ) = @_[ OBJECT, KERNEL, ARG0..$#_ ];
 	my $http_request = $args[0];
+	my $feed = $args[2];
+	$kernel->delay( 'request_feed', $feed->delay, $feed );
 	my $xml_feed = $args[1];
 	return if !(ref $xml_feed);
-	my $feed = $args[2];
 	my $cache_file = $self->tmpdir.'/'.$feed->name.'.feedcache';
 	my @entries;
 	my $ignore = 0;
@@ -73,7 +74,6 @@ event feed_received => sub {
 	my $count = @entries;
 	my @save_entries = splice(@entries, $count - $feed->max_headlines > 0 ? $count - $feed->max_headlines : 0, $feed->max_headlines);
 	scalar join("\n",@save_entries) > io($cache_file);
-	$kernel->delay( 'request_feed', $feed->delay, $feed );
 };
 
 event request_feed => sub {
@@ -81,9 +81,7 @@ event request_feed => sub {
 	$self->feed_client->yield('request',$feed->url,'feed_received',$feed);
 };
 
-sub add_feed {
-	shift->yield('_add_feed', @_);
-}
+sub add_feed { shift->yield('_add_feed', @_); }
 
 event _add_feed => sub {
 	my ( $self, $sender, $feed_args ) = @_[ OBJECT, SENDER, ARG0..$#_ ];
@@ -104,7 +102,7 @@ POE::Component::FeedAggregator - Watch multiple feeds (Atom or RSS) for new head
 
 =head1 VERSION
 
-version 0.008
+version 0.900
 
 =head1 SYNOPSIS
 
@@ -135,10 +133,6 @@ version 0.008
     });
   }
 
-=head1 DESCRIPTION
-
-This POE Component works a bit like L<POE::Component::RSSAggregator>. More info soon...
-
 =head1 SEE ALSO
 
 =over 4
@@ -159,10 +153,6 @@ L<XML::Feed>
 
 L<MooseX::POE>
 
-=item *
-
-L<POE::Component::RSSAggregator>
-
 =back
 
 =head1 AUTHOR
